@@ -107,8 +107,9 @@ $(function() {
             url: window.location.pathname + "/../ajax/simulatemerge",
             data: JSON.stringify({"Merge_books":selections}),
             success: function success(booTitles) {
+                $('#merge_from').empty();
                 $.each(booTitles.from, function(i, item) {
-                    $("<span>- " + item + "</span>").appendTo("#merge_from");
+                    $("<span>- " + item + "</span><p></p>").appendTo("#merge_from");
                 });
                 $("#merge_to").text("- " + booTitles.to);
 
@@ -811,11 +812,13 @@ function checkboxChange(checkbox, userId, field, field_index) {
 
 function BookCheckboxChange(checkbox, userId, field) {
     var value = checkbox.checked ? "True" : "False";
+    var element = checkbox;
     $.ajax({
         method: "post",
         url: getPath() + "/ajax/editbooks/" + field,
         data: {"pk": userId, "value": value},
         error: function(data) {
+            element.checked = !element.checked;
             handleListServerResponse([{type:"danger", message:data.responseText}])
         },
         success: handleListServerResponse
